@@ -1,6 +1,6 @@
 ;;; speechd-ssip.el --- SSIP driver
 
-;; Copyright (C) 2004, 2006 Brailcom, o.p.s.
+;; Copyright (C) 2004, 2006, 2008 Brailcom, o.p.s.
 
 ;; Author: Milan Zamazal <pdm@brailcom.org>
 
@@ -63,10 +63,12 @@
 (defmethod speechd.key ((driver speechd-ssip-driver) key)
   (speechd-say-key key))
 
+(defconst speechd-ssip--parameter-names (mapcar 'car speechd--parameter-names))
 (defmethod speechd.set ((driver speechd-ssip-driver) parameter value)
   (when (eq parameter 'priority)
     (setq parameter 'message-priority))
-  (speechd--set-parameter parameter value))
+  (when (memq parameter speechd-ssip--parameter-names)
+    (speechd--set-parameter parameter value)))
 
 (defmethod speechd.shutdown ((driver speechd-ssip-driver))
   (speechd-close-all))
